@@ -145,7 +145,7 @@ public:
     }
 
 private:
-    QWidget *const m_parentWidget;
+    QPointer<QWidget> m_parentWidget;
 };
 
 class KIOUiDelegate : public KIO::JobUiDelegate
@@ -192,12 +192,6 @@ KdePlatformTheme::KdePlatformTheme()
     QCoreApplication::setAttribute(Qt::AA_DontUseNativeMenuBar, false);
     setQtQuickControlsTheme();
 
-    static KIOUiFactory factory;
-    KIO::setDefaultJobUiDelegateFactory(&factory);
-
-    static KIOUiDelegate delegateExtension;
-    KIO::setDefaultJobUiDelegateExtension(&delegateExtension);
-
     KCountryFlagEmojiIconEngine::setGlobalDefaultFont(QFont(u"Noto Color Emoji, emoji"_qs));
 }
 
